@@ -13,13 +13,14 @@ from rest_framework import filters, viewsets
 from rest_framework.decorators import action
 from rest_framework.response import Response
 
-from django.db.models import Count, Max, OuterRef, Q, Subquery, Value
+from django.db.models import Count, Max, OuterRef, Prefetch, Q, Subquery, Value
 from django.db.models.fields import IntegerField
 from django.db.models.functions import Coalesce
 from django.utils import timezone
 
 from enterprise_data.api.v1 import serializers
-from enterprise_data.filters import ENROLLMENTS_CONSENT_TRUE_OR_NOENROLL_Q, AuditEnrollmentsFilterBackend
+from enterprise_data.constants import ANALYTICS_API_VERSION_1
+from enterprise_data.filters import AuditEnrollmentsFilterBackend, AuditUsersEnrollmentFilterBackend
 from enterprise_data.models import EnterpriseLearner, EnterpriseLearnerEnrollment
 from enterprise_data.paginators import EnterpriseEnrollmentsPagination
 
@@ -44,6 +45,7 @@ class EnterpriseViewSet(PermissionRequiredMixin, viewsets.ViewSet):
     authentication_classes = (JwtAuthentication,)
     pagination_class = DefaultPagination
     permission_required = 'can_access_enterprise'
+    API_VERSION = ANALYTICS_API_VERSION_1
 
     def paginate_queryset(self, queryset):
         """
@@ -229,16 +231,22 @@ class EnterpriseLearnerViewSet(EnterpriseViewSet, viewsets.ModelViewSet):
     """
     Viewset for routes related to Enterprise Learners.
     """
+    queryset = EnterpriseLearner.objects.all()
     serializer_class = serializers.EnterpriseLearnerSerializer
-    filter_backends = (filters.OrderingFilter,)
+    filter_backends = (filters.OrderingFilter, AuditUsersEnrollmentFilterBackend,)
     ordering_fields = '__all__'
     ordering = ('user_email',)
 
     def get_queryset(self):
         LOGGER.info("[ELV_ANALYTICS_API_V1] QueryParams: [%s]", self.request.query_params)
-
-        queryset = EnterpriseLearner.objects.filter(enterprise_customer_uuid=self.kwargs['enterprise_id'])
-        queryset = queryset.filter(ENROLLMENTS_CONSENT_TRUE_OR_NOENROLL_Q).distinct()
+        queryset = super().get_queryset().prefetch_related(
+            Prefetch(
+                'enrollments',
+                queryset=EnterpriseLearnerEnrollment.objects.filter(
+                    enterprise_customer_uuid=self.kwargs['enterprise_id']
+                )
+            ),
+        )
 
         has_enrollments = self.request.query_params.get('has_enrollments')
         if has_enrollments == 'true':
@@ -260,7 +268,7 @@ class EnterpriseLearnerViewSet(EnterpriseViewSet, viewsets.ModelViewSet):
 
         all_enrollments_passed = self.request.query_params.get('all_enrollments_passed')
         if all_enrollments_passed == 'true':
-            queryset = queryset.exclude(enrollments__has_passed=False)
+            queryset = queryset.filter(enrollments__has_passed=True)
         elif all_enrollments_passed == 'false':
             queryset = queryset.filter(enrollments__has_passed=False)
 
@@ -304,29 +312,24 @@ class EnterpriseLearnerViewSet(EnterpriseViewSet, viewsets.ModelViewSet):
             )
 
         LOGGER.info("[ELV_ANALYTICS_API_V1] QuerySet.Query: [%s]", queryset.query)
-
         return queryset
 
-    def list(self, request, **kwargs):  # pylint: disable=unused-argument
+    def list(self, request, **kwargs):
         """
         List view for learner records for a given enterprise.
         """
-        users = self.get_queryset()
+        users = self.get_queryset().filter(enterprise_customer_uuid=kwargs['enterprise_id'])
 
-        LOGGER.info("[ELV_ANALYTICS_API_V1] Filtering QuerySet")
         # do the sorting
         users = self.filter_queryset(users)
+        LOGGER.info("[ELV_ANALYTICS_API_V1] Filtered QuerySet.Query: [%s]", users.query)
 
-        LOGGER.info("[ELV_ANALYTICS_API_V1] Paginating QuerySet")
         # Bit to account for pagination
         page = self.paginate_queryset(users)
         if page is not None:
             serializer = self.get_serializer(page, many=True)
-            LOGGER.info("[ELV_ANALYTICS_API_V1] Returning Paginated Serialized Response")
             return self.get_paginated_response(serializer.data)
-        LOGGER.info("[ELV_ANALYTICS_API_V1] Serializing Response")
         serializer = self.get_serializer(users, many=True)
-        LOGGER.info("[ELV_ANALYTICS_API_V1] Returning Serialized Response")
         return Response(serializer.data)
 
 
